@@ -141,7 +141,7 @@ Crypt::TEA_PP - Pure Perl Implementation of the Tiny Encryption Algorithm
 
 =head1 VERSION
 
-version 0.0104
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -161,7 +161,7 @@ version 0.0104
 TEA is a 64-bit symmetric block cipher with a 128-bit key and a variable number of rounds (32 is recommended).
 It has a low setup time, and depends on a large number of rounds for security, rather than a complex algorithm.
 It was developed by David J. Wheeler and Roger M. Needham,
-and is described at <http://www.ftp.cl.cam.ac.uk/ftp/papers/djw-rmn/djw-rmn-tea.html>
+and is described at L<http://www.ftp.cl.cam.ac.uk/ftp/papers/djw-rmn/djw-rmn-tea.html>
 
 This module implements TEA encryption. It supports the Crypt::CBC interface, with the following functions.
 
@@ -186,13 +186,13 @@ The optional rounds parameter specifies the number of rounds of encryption to pe
 
     $cipher_text = $tea->encrypt($plain_text);
 
-Encrypts blocksize() bytes of $data and returns the corresponding ciphertext.
+Encrypts blocksize() bytes of $plain_text and returns the corresponding ciphertext.
 
 =head2 decrypt
 
     $plain_text = $tea->decrypt($cipher_text);
 
-Decrypts blocksize() bytes of $data and returns the corresponding plaintext.
+Decrypts blocksize() bytes of $cipher_text and returns the corresponding plaintext.
 
 =head1 SEE ALSO
 
